==> aroundme_0_7_0.zip: aroundme_0_7_0/aroundme/components/core/help.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


include "config/aroundme_core.config.php";
include "inc/aroundme_core.functions.php";



// START SESSION --------------------------------------------------------------
session_name($core_config['node']['php_session_name']);
session_start();


if (isset($_REQUEST['help'])) {
	$amn = $_REQUEST['help'];
	$amn_arr = explode("_", $amn, 2);
	$component_id = $amn_arr[0];
	$script_full_name = $amn;
	$script_name = $amn_arr[1];
		
}
else {
	$component_id = "core";
	$script_name = "login";
	$script_full_name = "core_login";
}

$component_path = "../" . $component_id . "/";
$language_path = $component_path . "language/" . $_SESSION['language_id'] . "/" . $_SESSION['template_title'] . "/";
 	$helpfile = $language_path . "help/" . $script_name . ".help.lang.php";

$helptxt = readTxtFile($helpfile);


// we format the space
if (!empty($helptxt)) {
	$helptxt = stripslashes($helptxt);
	
	require_once('class/Wiki/Wiki.php');
	require_once ('class/Wiki/Wiki/Parse.php');
	require_once ('class/Wiki/Wiki/Render.php');
	$wiki = new Text_Wiki();
	$wiki->disableRule('freelink');
	$wiki->disableRule('wikilink');
	$wiki->setRenderConf('xhtml', 'image', 'base', "get_file.php?file=");
	
	$helptxt = $wiki->transform($helptxt, 'Xhtml');
	
	// SETUP TEMPLATE
	$template_path_core = "template/" . $_SESSION['template_title'] . "/";
	
	require_once('class/Template.class.php');
	$tpl = & new Template($template_path_core); // outer template
	$tpl->set('template_path_core', $template_path_core);
	$tpl->set('helptxt', $helptxt);
	
	// GET LANGUAGES
	$lang = array();
	$language_path = "language/" . $_SESSION['language_id'] . "/" . $_SESSION['template_title'] . "/";
	
	require_once($language_path . 'help.lang.php');
	
	$tpl->set('lang', $lang); // language
}

$outer_template_file = "help.tpl.php";

echo $tpl->fetch($outer_template_file);


?>

==> aroundme_0_7_6.zip: aroundme_0_7_6/aroundme/components/core/help.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


include "config/aroundme_core.config.php";
include "inc/aroundme_core.functions.php";



// START SESSION --------------------------------------------------------------
session_name($core_config['node']['php_session_name']);
session_start();



$component_path = "../core/";
// SETUP TEMPLATE
$template_path_core = "template/" . $_SESSION['template_title'] . "/";
	
require_once('class/Template.class.php');
$tpl = & new Template($template_path_core); // outer template
$tpl->set('template_path_core', $template_path_core);
	
// GET LANGUAGES
$lang = array();
$language_path = "language/" . $_SESSION['language_id'] . "/" . $_SESSION['template_title'] . "/";

require_once($language_path . 'help.lang.php');

$tpl->set('lang', $lang); // language

$outer_template_file = "help.tpl.php";

echo $tpl->fetch($outer_template_file);

?>
